@@ -1,10 +1,15 @@
 import os
 import logging
 
-if __name__ == '__main__':
-
+def run():
+    '''
+        This function starts the lifecycle consumer which will start
+        listening for OpenEthics lifecycle events, and then it will start
+        polling the RMAS ESB for RMAS events (polling is blocking so you must 
+        start the liefecycle consumer first).
+    '''
     #this has to come first before you import any other modules otherwsise the settings won't be intitialized
-    os.environ.setdefault("RMAS_ADAPTER_SETTINGS", "settings")
+    os.environ.setdefault("RMAS_ADAPTER_SETTINGS", "rmas_oe_adapter.settings")
     
     logging.basicConfig(level=logging.INFO)
     
@@ -12,4 +17,8 @@ if __name__ == '__main__':
     from rmas_oe_adapter import lifecycle_consumer
     
     lifecycle_consumer.connect()#start listening for oe lifecycle events
-    start_polling()#start polling for rmas events
\ No newline at end of file
+    start_polling()#start polling for rmas events
+
+if __name__ == '__main__':
+    run()
+    
\ No newline at end of file
